package com.autentia.adictos.hs.model;

import java.util.Date;

import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;

import org.apache.solr.analysis.HTMLStripStandardTokenizerFactory;
import org.apache.solr.analysis.ISOLatin1AccentFilterFactory;
import org.apache.solr.analysis.LowerCaseFilterFactory;
import org.apache.solr.analysis.SnowballPorterFilterFactory;
import org.apache.solr.analysis.StopFilterFactory;
import org.hibernate.search.annotations.Analyzer;
import org.hibernate.search.annotations.AnalyzerDef;
import org.hibernate.search.annotations.Boost;
import org.hibernate.search.annotations.DateBridge;
import org.hibernate.search.annotations.DocumentId;
import org.hibernate.search.annotations.Field;
import org.hibernate.search.annotations.Index;
import org.hibernate.search.annotations.Indexed;
import org.hibernate.search.annotations.IndexedEmbedded;
import org.hibernate.search.annotations.Parameter;
import org.hibernate.search.annotations.Resolution;
import org.hibernate.search.annotations.Store;
import org.hibernate.search.annotations.TokenFilterDef;
import org.hibernate.search.annotations.TokenizerDef;

@Entity
@Indexed
@AnalyzerDef(name = "Analizador_Noticia", tokenizer = @TokenizerDef(factory = HTMLStripStandardTokenizerFactory.class), filters = {
		@TokenFilterDef(factory = ISOLatin1AccentFilterFactory.class),
		@TokenFilterDef(factory = StopFilterFactory.class, params = {
				@Parameter(name = "words", value = "spanish-stoplist.txt"),
				@Parameter(name = "ignoreCase", value = "true") }),
		@TokenFilterDef(factory = LowerCaseFilterFactory.class),
		@TokenFilterDef(factory = SnowballPorterFilterFactory.class, params = { @Parameter(name = "language", value = "Spanish") }) })
public class Noticia {

	@Id
	@GeneratedValue(strategy = GenerationType.AUTO)
	@DocumentId
	private Long id;

	@Temporal(TemporalType.TIMESTAMP)
	@Field(index = Index.UN_TOKENIZED, store = Store.NO)
	@DateBridge(resolution = Resolution.DAY)
	@Analyzer(definition = "Analizador_Noticia")
	private Date fechaPublicacion;

	@Field(index = Index.TOKENIZED, store = Store.NO)
	@Boost(2.0f)
	@Analyzer(definition = "Analizador_Noticia")
	private String titular;

	@Field(index = Index.TOKENIZED, store = Store.NO)
	@Boost(1.5f)
	@Analyzer(definition = "Analizador_Noticia")
	private String entradilla;

	/**
	 * El cuerpo de la noticia vendrá en HTML
	 */
	@Field(index = Index.TOKENIZED, store = Store.NO)
	@Analyzer(definition = "Analizador_Noticia")
	private String cuerpo;

	@ManyToOne
	@JoinColumn(name = "id_autor")
	@IndexedEmbedded
	private Autor autor;

	public Long getId() {
		return id;
	}

	public void setId(Long id) {
		this.id = id;
	}

	public Date getFechaPublicacion() {
		return fechaPublicacion;
	}

	public void setFechaPublicacion(Date fechaPublicacion) {
		this.fechaPublicacion = fechaPublicacion;
	}

	public String getTitular() {
		return titular;
	}

	public void setTitular(String titular) {
		this.titular = titular;
	}

	public String getEntradilla() {
		return entradilla;
	}

	public void setEntradilla(String entradilla) {
		this.entradilla = entradilla;
	}

	public String getCuerpo() {
		return cuerpo;
	}

	public void setCuerpo(String cuerpo) {
		this.cuerpo = cuerpo;
	}

	public Autor getAutor() {
		return autor;
	}

	public void setAutor(Autor autor) {
		this.autor = autor;
	}

	@Override
	public String toString() {
		return "Noticia [titular=" + titular + ", entradilla=" + entradilla + ", fechaPublicacion=" + fechaPublicacion
				+ ", autor=" + autor + "]";
	}

}
